#
# spec file for package scdoc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scdoc
Version:        1.11.3
Release:        2.2
Summary:        A man page generator written in C99
License:        MIT
Group:          Development/Tools/Doc Generators
URL:            https://git.sr.ht/~sircmpwn/scdoc/
Source:         https://git.sr.ht/~sircmpwn/scdoc/archive/%{version}.tar.gz
Source1:        scdoc-rpmlintrc
Patch0:         scdoc-1.6.1-makefile.patch
BuildRequires:  autoconf
BuildRequires:  gcc
BuildRequires:  glibc-devel-static
BuildRequires:  make

%description
scdoc is a man page generator written for POSIX systems written in C99.

%prep
%autosetup -p1

%build
%make_build PREFIX=%{_prefix}

%install
%make_install PREFIX=%{_prefix} PCDIR=%{_datadir}/pkgconfig %{?_smp_mflags}

%files
%{_bindir}/scdoc
%{_mandir}/man?/scdoc.?%{?ext_man}
%{_datadir}/pkgconfig/scdoc.pc

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sat Feb 17 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.11.3:
  * Fix clang 15 -Wstrict-prototypes warnings
  * Remove useless re-declarations of standard functions
    get rid of some unused includes
  * Use .PP for paragraph breaks
  * scdoc(1), scdoc(5): follow conventions more closely
  * Fix formatting of escaped backticks
  * scdoc.5: fix capitalization of subsection headers
  * scdoc.5: fix formatting in the preamble
  * man: add section about SOURCE_DATE_EPOCH
  * Emit '\e' instead of '\\'
* Wed Nov 17 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.11.2:
  * Add uninstall target
  * Escape ' at the beginning of lines
  * Clean up the installation process
  * Check for and abort on failed memory allocations
  * Disallows differing row lengths in table
- Refresh scdoc-1.6.1-makefile.patch
* Mon Dec  7 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.11.1:
  * string.c: swap calloc arguments
  * Cast ctype.h inputs to unsigned char
  * Suppress sentence spacing after end-of-sentence characters.
* Thu Jul 30 2020 Michael Vetter <mvetter@suse.com>
- Use _datadir macro
* Tue Jun 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.11.0:
  * Section needs to be explicitly defined
  * Allow subsection in preamble
  * Add basic working tests for line breaks parsing
  * Fix parsing of line breaks without newline
  * Fix parsing of line breaks followed by underlined text
* Mon Feb 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.10.1:
  * Replace str_t with struct str
  * Expand preamble written to man page output
  * Fix timezone-dependent tests
  * Fix `date --date` dependent test
* Thu Sep 12 2019 mvetter@suse.com
- Update to 1.10.0:
  * tables: add expand options
  * Add contrib/_incr_version
- Update scdoc-1.6.1-makefile.patch
* Fri Aug 23 2019 mvetter@suse.com
- Update to 1.9.7:
  * Remove unnecessary `closed` variable in parse_list
  * Fix bug preventing indented literal blocks
* Thu Jul 11 2019 mvetter@suse.com
- Update to 1.9.6:
  * Fix regression with manual name check
- Changes from 1.9.5:
  * Use TZ=UTC in test case
  * Disallow invalid name characters
  * Enforce 1-step indentation
* Tue Mar 12 2019 mvetter@suse.com
- bsc#1128844: Use correct prefix in pkgconfig file
* Tue Mar  5 2019 mvetter@suse.com
- Update to 1.9.4:
  * Fix SOURCE_DATE_EPOCH test w/busybox date
  * Drop install -D flag after acb0f64a7b73
  * Fix the "Ignores underscores in underlined words" test
  * Add a pkg-config template
* Mon Mar  4 2019 mvetter@suse.com
- Update to 1.9.3:
  * parse_text: return if next is UTF8_INVALID
* Thu Feb 28 2019 Michael Vetter <mvetter@suse.com>
- Update to 1.9.1:
  Fix underscores in underlined words
* Mon Feb 25 2019 mvetter@suse.com
- Install pc file in /usr/share/pkgconfig/ instead of /usr/lib
* Mon Feb 25 2019 mvetter@suse.com
- Update to 1.9.0:
  * Replace localtime with gmtime
  * Add pkg-config file, scdoc -v
  * Allow continuation of table cells on the next line
  * Fix link to mailing list in README
- Add scdoc-rpmlintrc: allow .pc file
* Wed Feb  6 2019 mvetter@suse.com
- Update to 1.8.1:
  * Use !isalnum instead of isspace for this_stuff
* Mon Feb  4 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Mon Feb  4 2019 mvetter@suse.com
- Update to 1.8.0:
  * Use a more robust approach for in-word-underscores
  * Deal with bogus uninitialized warning (thx gcc)
  * Ignore underscores in the middle_of_a_word
- Update scdoc-1.6.1-makefile.patch
* Fri Jan 25 2019 mvetter@suse.com
- Add scdoc-1.6.1-makefile.patch:
  Disable static linking to fix W: statically-linked-binary and
  W: position-independent-executable-suggested
* Fri Jan 25 2019 mvetter@suse.com
- Package scdoc 1.6.1 for openSUSE
